//
//  BaseDemoViewController.m
//  AAIGlobalIQASDKDemo
//
//  Created by advance on 2022/9/23.
//

#import "BaseDemoViewController.h"
#include <Photos/Photos.h>
@import AAIGlobalIQASDK;

@interface BaseDemoViewController ()

@end

@implementation BaseDemoViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    
    self.view.backgroundColor = [UIColor whiteColor];
    
    // load regin list
    NSString *countryListFilePath = [[NSBundle mainBundle] pathForResource:@"country_list" ofType:@"json"];
    NSData *countryListData = [NSData dataWithContentsOfFile:countryListFilePath];
    NSArray<NSDictionary *> *countryList = [NSJSONSerialization JSONObjectWithData:countryListData options:0 error:nil];
    NSMutableArray<NSString *> *reginList = [[NSMutableArray alloc] initWithCapacity:countryList.count];
    for (NSDictionary *item in countryList) {
        [reginList addObject:item[@"iso2Code"]];
    }
    _reginList = reginList;
    
    _cardTypeList = @[@(AAIIQACardTypeIDCard),
                      @(AAIIQACardTypeDrivingLicense),
                      @(AAIIQACardTypeUMID),
                      @(AAIIQACardTypeSSS),
                      @(AAIIQACardTypeTIN),
                      @(AAIIQACardTypePassport),
                      @(AAIIQACardTypeVOTERID),
                      @(AAIIQACardTypeNATIONALID),
                      @(AAIIQACardTypePRC),
                      @(AAIIQACardTypePAGIBIG),
                      @(AAIIQACardTypePOSTALID)];
    _cardTypeStrList = @[@"ID_CARD",
                         @"DRIVING_LICENSE",
                         @"UMID",
                         @"SSS",
                         @"TIN",
                         @"PASSPORT",
                         @"VOTERID",
                         @"NATIONALID",
                         @"PRC",
                         @"PAGIBIG",
                         @"POSTALID"];
    _cardSideList = @[@(AAIIQACardSideFront), @(AAIIQACardSideBack)];
    _cardSideStrList = @[@"FRONT", @"BACK"];
    _currReginIdx = 0;
    _currCardTypeIdx = 0;
    _currCardSideIdx = 0;
    
    _opModeList = @[@(AAIIQAOperatingModeDefault), @(AAIIQAOperatingModeScanning), @(AAIIQAOperatingModePhoto)];
    _opModeStrList = @[@"Default", @"Scan", @"Photo"];
    _currOpModeIdx = 0;
    
    UIPickerView *reginPV = [self addPVWithFrame:CGRectZero tag:1];
    UIPickerView *cardTypePV = [self addPVWithFrame:CGRectZero tag:2];
    UIPickerView *cardSidePV = [self addPVWithFrame:CGRectZero tag:3];
    UIPickerView *opModePV = [self addPVWithFrame:CGRectZero tag:4];
    
    NSString *btnTitle = [self btnTitle];
    UIButton *btn = [self button:btnTitle frame:CGRectZero action:@selector(tapSDKBtnAction)];
    [self.view addSubview:btn];
    
    UITextView *tv = [[UITextView alloc] initWithFrame:CGRectZero];
    tv.editable = NO;
    tv.font = [UIFont systemFontOfSize:14];
    [self.view addSubview:tv];
    _tv = tv;
    
    UIView *sv = self.view;
    UIStackView *stackView = [[UIStackView alloc] initWithArrangedSubviews:@[reginPV, cardTypePV, cardSidePV]];
    stackView.axis = UILayoutConstraintAxisHorizontal;
    stackView.distribution = UIStackViewDistributionFillProportionally;
    stackView.translatesAutoresizingMaskIntoConstraints = NO;
    [sv addSubview:stackView];
    
    opModePV.translatesAutoresizingMaskIntoConstraints = NO;
    [sv addSubview:opModePV];
    
    btn.translatesAutoresizingMaskIntoConstraints = NO;
    tv.translatesAutoresizingMaskIntoConstraints = NO;
    
    NSArray<NSLayoutConstraint *> *pvCons = @[
        [stackView.leftAnchor constraintEqualToAnchor:sv.leftAnchor constant:8],
        
        [AAIIQACommUtil topContraintOf:stackView toSV:sv constant:0],
        [stackView.heightAnchor constraintEqualToConstant:88],
        [stackView.rightAnchor constraintEqualToAnchor:sv.rightAnchor constant:-8],
        
        [opModePV.topAnchor constraintEqualToAnchor:stackView.bottomAnchor constant:8],
        [AAIIQACommUtil leftContraintOf:opModePV toSV:sv constant:8],
        [opModePV.widthAnchor constraintEqualToConstant:140],
        [opModePV.heightAnchor constraintEqualToConstant:88],
#if AAIDEMO == 1
        [ackTextField.topAnchor constraintEqualToAnchor:opModePV.bottomAnchor constant:20],
        [ackTextField.leftAnchor constraintEqualToAnchor:opModePV.leftAnchor constant:8],
        [ackTextField.widthAnchor constraintEqualToConstant:240],
        [ackTextField.heightAnchor constraintEqualToConstant:40],
        [btn.topAnchor constraintEqualToAnchor:ackTextField.bottomAnchor constant:20],
#else
        [btn.topAnchor constraintEqualToAnchor:opModePV.bottomAnchor constant:8],
#endif
        [btn.leftAnchor constraintEqualToAnchor:opModePV.leftAnchor constant:8],
        [btn.widthAnchor constraintEqualToConstant:140],
        [btn.heightAnchor constraintEqualToConstant:40],
        
        [tv.topAnchor constraintEqualToAnchor:btn.bottomAnchor constant:8],
        [tv.leftAnchor constraintEqualToAnchor:sv.leftAnchor constant:8],
        [tv.rightAnchor constraintEqualToAnchor:sv.rightAnchor constant:-8],
        [tv.bottomAnchor constraintEqualToAnchor:sv.bottomAnchor constant:-8],
    ];
    
    [NSLayoutConstraint activateConstraints:pvCons];
}

- (UIButton *)button:(NSString *)title frame:(CGRect)frame action:(SEL)action
{
    UIButton *btn = [UIButton buttonWithType:UIButtonTypeCustom];
    btn.frame = frame;
    [btn setTitle:title forState:UIControlStateNormal];
    [btn setTitleColor:[UIColor whiteColor] forState:UIControlStateNormal];
    [btn addTarget:self action:action forControlEvents:UIControlEventTouchUpInside];
    btn.backgroundColor = [UIColor grayColor];
    
    return btn;
}

- (UIPickerView *)addPVWithFrame:(CGRect)frame tag:(NSInteger)tag
{
    UIPickerView *pv = [[UIPickerView alloc] initWithFrame:frame];
    pv.layer.borderWidth = 1;
    pv.layer.borderColor = UIColor.lightGrayColor.CGColor;
    
    pv.dataSource = self;
    pv.delegate = self;
    pv.tag = tag;
    [self.view addSubview:pv];
    return pv;
}

- (NSString *)btnTitle
{
    NSString *btnTitle = [NSString stringWithFormat:@"%@ Test", [AAIGlobalIQASDK sdkVersion]];
    return btnTitle;
}

- (void)tapSDKBtnAction
{
    
}

- (void)saveImageToPhoto:(UIImage *)image
{
    UIImageWriteToSavedPhotosAlbum(image, nil, nil, nil);
}

- (void)processIQAResult:(AAIGlobalIQAResult *)result
{
    NSMutableString *resultStr = [[NSMutableString alloc] init];
    if (result.success) {
        [resultStr appendString:@"SUCCESS"];
        [resultStr appendFormat:@"\n\nImage Size:%@", NSStringFromCGSize(result.cardImg.size)];
        [resultStr appendFormat:@"\n\nIDVID:%@", result.IDVID];
        [resultStr appendFormat:@"\n\ntransacitonID:%@", result.transactionId];
        [resultStr appendFormat:@"\n\nPictureType:%@", result.pictureType];
        
        if (result.ocrResult) {
            NSData *jsonData = [NSJSONSerialization dataWithJSONObject:result.ocrResult options:NSJSONWritingPrettyPrinted error:nil];
            NSString *jsonStr = [[NSString alloc] initWithData:jsonData encoding:NSUTF8StringEncoding];
            [resultStr appendFormat:@"\n\nOCRResult:\n%@", jsonStr];
        }
        
        if (result.idForgeryResult) {
            NSData *jsonData = [NSJSONSerialization dataWithJSONObject:result.idForgeryResult options:NSJSONWritingPrettyPrinted error:nil];
            NSString *jsonStr = [[NSString alloc] initWithData:jsonData encoding:NSUTF8StringEncoding];
            [resultStr appendFormat:@"\n\nidForgeryResult:\n%@", jsonStr];
        }
        
        [self saveImageToPhoto:result.cardImg];
    } else {
        [resultStr appendFormat:@"Error Code:%@", result.errorCode];
        if (result.errorMsg) {
            [resultStr appendFormat:@"\n\nError Msg:%@", result.errorMsg];
        }
        
        if (result.transactionId) {
            [resultStr appendFormat:@"\n\ntransacitonID:%@", result.transactionId];
        }
    }
    _tv.text = resultStr;
}


# pragma mark UIPickerView datasource delegate
- (NSInteger)pickerView:(UIPickerView *)pickerView numberOfRowsInComponent:(NSInteger)component
{
    switch (pickerView.tag) {
        case 1:
            return _reginList.count;
            break;
        case 2:
            return _cardTypeList.count;
            break;
        case 3:
            return _cardSideList.count;
            break;
        case 4:
            return _opModeStrList.count;
            break;
        default:
            return 0;
            break;
    }
}

- (NSInteger)numberOfComponentsInPickerView:(UIPickerView *)pickerView
{
    return 1;
}

- (NSString *)pickerView:(UIPickerView *)pickerView titleForRow:(NSInteger)row forComponent:(NSInteger)component
{
    switch (pickerView.tag) {
        case 1: {
            return _reginList[row];
        } break;
        case 2: {
            return _cardTypeStrList[row];
        } break;
        case 3: {
            return _cardSideStrList[row];
        } break;
        case 4: {
            return _opModeStrList[row];
        } break;
        default:
            return nil;
            break;
    }
}

- (void)pickerView:(UIPickerView *)pickerView didSelectRow:(NSInteger)row inComponent:(NSInteger)component
{
    switch (pickerView.tag) {
        case 1: {
            _currReginIdx = row;
        } break;
        case 2: {
            _currCardTypeIdx = row;
        } break;
        case 3: {
            _currCardSideIdx = row;
        } break;
        case 4: {
            _currOpModeIdx = row;
        } break;
        default:
            break;
    }
}

@end
