//
//  AAICustomUIDemo2ViewController.m
//  AAIGlobalIQASDKDemo
//
//  Created by advance on 2022/9/23.
//

#import "AAICustomUIDemo2ViewController.h"

#import "AAICustomTipView2.h"
#import "AAICustomOverlayView2.h"
#import "AAICustomScanController2.h"
#import "AAICustomPorTakePhotoTipView2.h"
#import "AAICustomDetectionTimeoutAlertView2.h"

@interface AAICustomUIDemo2ViewController ()<AAIGlobalIQADelegate, AAIIQATipViewDataSource>

@end

@implementation AAICustomUIDemo2ViewController

- (void)viewDidLoad {
    [super viewDidLoad];
}

- (void)tapSDKBtnAction
{
    AAIIQACardType cardType = [_cardTypeList[_currCardTypeIdx] integerValue];
    AAIIQACardSide cardSide = [_cardSideList[_currCardSideIdx] integerValue];
    // 1. Create AAIGlobalIQAConfig
    AAIGlobalIQAConfig *config = [AAIGlobalIQAConfig initWithRegion:_reginList[_currReginIdx] cardType:cardType cardSide:cardSide];
    config.delegate = self;
    config.callbackAfterPageDismissed = YES;
    
    // Configure SDK operation mode
    AAIIQAOperatingMode opMode = [_opModeList[_currOpModeIdx] integerValue];
    config.operatingMode = opMode;
    
     // Configure SDK UI
    config.detectionTimeoutInterval = 20;
    
    // Customize the SDK font
    config.uiConfig.fontName = @"Chalkduster";
    
    // Customize the navigation bar title
    config.uiConfig.navBarAttrTitle = [[NSAttributedString alloc] initWithString:@"" attributes:nil];
    
    // Specify viewfinder(Camera overlay view) color.
    config.uiConfig.viewfinderColor = [UIColor redColor];
    
    config.uiConfig.toolButtonThemeColor = [UIColor blueColor];
    
    config.uiConfig.takePhotoTipLeftIconVisible = NO;
    config.uiConfig.takePhotoTipBackgroundColor = [UIColor clearColor];
    
    // Customize the tip view styled text in photo mode.
    NSMutableParagraphStyle *paragraphStyle = NSMutableParagraphStyle.new;
    paragraphStyle.alignment = NSTextAlignmentCenter;
    UIFont *customFont = [UIFont fontWithName:config.uiConfig.fontName size:15];
    NSDictionary *takePhotoTipAttr = @{NSFontAttributeName: customFont, NSForegroundColorAttributeName: [UIColor redColor], NSParagraphStyleAttributeName:paragraphStyle};
    config.uiConfig.takePhotoTipAttrText = [[NSAttributedString alloc] initWithString:@"Take Photo manually" attributes:takePhotoTipAttr];
    
    config.uiConfig.previewPhotoTipBackgroundColor = [UIColor clearColor];
    config.uiConfig.previewPhotoTipLeftIconVisible = NO;
    
    // Customize the tip view styled text in preview mode.
    NSDictionary *normalAttr = @{NSFontAttributeName: customFont, NSForegroundColorAttributeName: [UIColor redColor], NSParagraphStyleAttributeName:paragraphStyle};
    config.uiConfig.previewPhotoTipAttrText = [[NSAttributedString alloc] initWithString:@"Please ensure that all data on your documents is visible and readable." attributes:normalAttr];
    
    /*
    // Specify SDK language
    config.languageLprojName = @"id";
    */
    
    config.uiConfig.cameraViewMarginLRInPortraitMode = @(12);
    config.uiConfig.flipCameraBtnVisible = NO;
    config.uiConfig.lightBtnVisible = NO;
    config.uiConfig.timerLabelVisible = NO;
    
    // Hide the default topDescView and add our own custom topDescView to the "AAICustomScanController2" class.
    config.uiConfig.topDescViewVisible = NO;
    
    // Customize the "AAIIQAScanController" by specify the class "AAICustomScanController2" (which inherits from "AAIIQAScanController").
    [config registerClass:[AAICustomScanController2 class] forModule:AAIIQAModuleTypeScanController];
    
    // Customize the viewfinder(camera overlay view) style in scan mode.
    [config registerClass:[AAICustomOverlayView2 class] forModule:AAIIQAModuleTypeOverlayViewOfScanVC];
    
    // Customize the viewfinder(image overlay view) style in preview mode.
    [config registerClass:[AAICustomOverlayView2 class] forModule:AAIIQAModuleTypeOverlayViewOfPreviewImgVC];
    
    // Specify the tipViewDataSource to provide your custom tipView(in scan mode).
    config.tipViewDataSource = self;
    
    
    /*
    // <AAIIQATakePhotoTipViewDataSource>
    // If the ui configuration available for the tipView in photo mode does not meet your needs,
    // you can create a tip view by specifying this property.
    config.takePhotoTipViewDataSource = self;
    */
    
    /* imageName list:
     advance_iqa_scan: An image to show the scan animation.
     advance_iqa_tip_capture: The icon in the countdown pop-up view after the scan times out.
     iqa_back: Icon of navigation bar back button.
     iqa_land_confirm: Confirm button icon in landscape take photo mode.
     iqa_land_retake: Retake button icon in landscape take photo mode.
     iqa_light_off: Icon of flashlight off button.
     iqa_light_on: Icon of flashlight on button.
     iqa_scan_processing: The icon displayed at the bottom of the vertical screen (local string key is: "hold_phone").
     iqa_scan_successfully: The icon displayed at the bottom of the vertical screen (local string key is: "iqa_scan_successfully").
     iqa_scan_warning: The icon displayed at the bottom of the vertical screen (local string key is: "iqa_card_poor_quality").
     iqa_take_photo_tip: The tip icon displayed at the bottom of the viewfinder view (local string key is: "iqa_take_photo_tips").
     iqa_take_photo: Icon of take photo button.
     iqa_transform_camera: Icon of switch camera button.
    */
    /*
    // You can implement this block to customize the images used in the SDK.
    config.uiConfig.loadImage = ^UIImage * _Nonnull(NSString * _Nonnull imgName, UIImage * _Nonnull img) {
        if ([imgName isEqualToString:@"iqa_scan_successfully"]) {
            return [UIImage imageNamed:@"ok"];
        }
        return img;
    };
    */
    
    /*
    // You can implement this block to customize the localized strings used in the SDK.
    // For all available keys, see "AAIGlobalIQASDK.framework/AAIIQALanguageString.bundle/en.lproj/Localizable.strings"
    config.uiConfig.loadLocalizedString = ^NSString * _Nonnull(NSString * _Nonnull key, NSString * _Nonnull value, NSString * _Nonnull language) {
        if ([key isEqualToString:@"iqa_top_desc"]) {
            if ([language isEqual:@"en"]) {
                return @"My test string";
            }
        }

        return value;
    };
     */
    
    // 2. Init SDK
    [AAIGlobalIQASDK initWithConfig:config];
    
    /*
     3. Check whether the license is valid.
     The license content is obtained by your server calling our openapi.
     In order to demonstrate this SDK, we directly put the content of the license into the file,
     in fact, you should call your server api to get the license content.
     Note that the "setLicenseAndCheck:" method MUST BE CALLED before calling "startWithRootVC:".
     */
    NSString *path = [[NSBundle mainBundle] pathForResource:@"SDK-DEMO-LICENSE.txt" ofType:nil];
    NSString *data = [NSString stringWithContentsOfFile:path encoding:NSUTF8StringEncoding error:nil];
    data = [data stringByTrimmingCharactersInSet:[NSCharacterSet whitespaceAndNewlineCharacterSet]];
    NSString *result = [AAIGlobalIQASDK setLicenseAndCheck:data];
    if ([result isEqualToString:@"SUCCESS"]) {
        // 4. Show SDK page
        [AAIGlobalIQASDK startWithRootVC:self];
    } else {
        _tv.text = result;
        if ([result isEqualToString:@"LICENSE_EXPIRE"]) {
            NSLog(@"LICENSE_EXPIRE: please call your server's api to generate a new license");
        } else if ([result isEqualToString:@"APPLICATION_ID_NOT_MATCH"]) {
            NSLog(@"APPLICATION_ID_NOT_MATCH: please bind your app's bundle identifier on our cms website, then recall your server's api to generate a new license");
        } else {
            NSLog(@"%@", result);
        }
    }
}

# pragma mark AAIGlobalIQADelegate

- (void)iqaOnDetectionComplete:(AAIGlobalIQAResult *)result
{
    [self processIQAResult:result];
}

/*
// You implement this method to add your own custom processing
- (void)iqaOnDectionSuccess:(UIView *)contentView completionHandler:(void (^)(void))completionHandler
{
//     You can add your own custom processing,
//     such as animated pop-ups to indicate successful detection,
//     after your processing is complete, you must call the completionHandler()
    completionHandler();
}
*/

/*
 // If you want to customize the timeout alert view, you can implement this method to display your own timeout alert view.
- (void)iqaOnDetectionTimeout:(UIView *)contentView completionHandler:(void (^)(AAIIQADetectionTimeoutDisposition))completionHandler
{
    AAICustomDetectionTimeoutAlertView2 *alertView = [[AAICustomDetectionTimeoutAlertView2 alloc] init];
    alertView.translatesAutoresizingMaskIntoConstraints = NO;
    [contentView addSubview:alertView];
    NSArray<NSLayoutConstraint *> *cons = @[
        [alertView.topAnchor constraintEqualToAnchor:contentView.topAnchor],
        [alertView.leftAnchor constraintEqualToAnchor:contentView.leftAnchor],
        [alertView.bottomAnchor constraintEqualToAnchor:contentView.bottomAnchor],
        [alertView.rightAnchor constraintEqualToAnchor:contentView.rightAnchor],
    ];
    [NSLayoutConstraint activateConstraints:cons];
    [alertView showWithAnimation];

    dispatch_after(dispatch_time(DISPATCH_TIME_NOW, (int64_t)(3 * NSEC_PER_SEC)), dispatch_get_main_queue(), ^{
        [alertView removeFromSuperview];
        completionHandler(AAIIQADetectionTimeoutDispositionUsePhotoMode);
    });
}
*/

// Required methods for protocol <AAIIQATipViewDataSource>.
- (UIView<AAIIQADetectionDelegate> *)iqaCreateTipView:(BOOL)isPortratOrientation
{
    // Here we take only custom tipView in protrait mode as an example
    if (isPortratOrientation) {
        return [[AAICustomTipView2 alloc] init];
    } else {
        // Use default tip view in landscape mode
        return nil;
    }
}

/*
// Required methods for protocol <AAIIQATakePhotoTipViewDataSource>.
- (UIView *)iqaCreateTakePhotoTipView:(BOOL)isPortratOrientation
{
    if (isPortratOrientation) {
        return [[AAICustomPorTakePhotoTipView2 alloc] init];
    } else {
        // Use default tip view in landscape mode
        return nil;
    }
}
*/

@end
