//
//  AAICustomTipView2.m
//  AAIGlobalIQASDKDemo
//
//  Created by advance on 2022/9/20.
//

#import "AAICustomTipView2.h"

@interface AAICustomTipView2()
{
    UIView *_contentView;
    UILabel *_descLabel;
}
@end
@implementation AAICustomTipView2

- (instancetype)initWithFrame:(CGRect)frame
{
    self = [super initWithFrame:frame];
    if (self) {
        [self createSubviews];
    }
    return self;
}

- (void)createSubviews
{
    UIView *contentView = [self createContentView];
    
    // You can adjust the contentHeight to meet your needs.
    CGFloat marginLeft = 12;
    CGFloat contentHeight = 80;
    NSNumber *marginLeftObj = [AAIGlobalIQASDK sdkConfig].uiConfig.cameraViewMarginLRInPortraitMode;
    if (marginLeftObj) {
        marginLeft = [marginLeftObj floatValue];
    }
    
    [self addSubview:contentView];
    CGSize screenSize = [UIScreen mainScreen].bounds.size;
    CGFloat sw = MIN(screenSize.width, screenSize.height);
    NSArray *allCons = @[
        [contentView.widthAnchor constraintEqualToConstant:(sw - 2 * marginLeft)],
        [contentView.heightAnchor constraintEqualToConstant:contentHeight],
        
        [contentView.centerXAnchor constraintEqualToAnchor:self.centerXAnchor],
        [contentView.centerYAnchor constraintEqualToAnchor:self.centerYAnchor],
    ];
    
    [NSLayoutConstraint activateConstraints:allCons];
    
    _contentView = contentView;
}

- (UIView *)createContentView
{
    AAIGlobalIQAUIConfig *uiConfig = [AAIGlobalIQASDK sdkConfig].uiConfig;
    UIView *contentView = [[UIView alloc] init];
    contentView.translatesAutoresizingMaskIntoConstraints = NO;
    contentView.layer.cornerRadius = 8;
    
    // You can adjust the font, textColor to meet your needs.
    UILabel *label = [[UILabel alloc] init];
    label.font = [AAIIQACommUtil fontWithSize:14 isBold:NO];
    label.textColor = uiConfig.primaryTextColor;
    label.numberOfLines = 0;
    label.textAlignment = NSTextAlignmentCenter;
    label.translatesAutoresizingMaskIntoConstraints = NO;
    [contentView addSubview:label];
    
    NSArray *allCons = @[
        [label.leftAnchor constraintEqualToAnchor:contentView.leftAnchor constant:20],
        [label.rightAnchor constraintEqualToAnchor:contentView.rightAnchor constant:-20],
        [label.centerYAnchor constraintEqualToAnchor:contentView.centerYAnchor]
    ];
    
    [NSLayoutConstraint activateConstraints:allCons];

    _descLabel = label;
    
    return contentView;
}

- (void)setBcgColor:(UIColor *)bcgColor borderColor:(UIColor *)borderColor;
{
    CALayer *layer = _contentView.layer;
    _contentView.backgroundColor = bcgColor;
    
    layer.borderColor = borderColor.CGColor;
    layer.borderWidth = 2;
}

- (void)iqaOnDetectionWarn:(AAIIQAWarnCode)warnCode
{
    // You can adjust the bcgColor, borderColor to meet your needs.
    NSString *stateKey = nil;
    switch (warnCode) {
        case AAIIQAWarnCodeNoCard:
            stateKey = @"no_card";
            [self setBcgColor:[UIColor colorWithRed:0.949 green:0.949 blue:0.949 alpha:1] borderColor:[UIColor colorWithRed:0.886 green:0.886 blue:0.886 alpha:1]];
            break;
        case AAIIQAWarnCodeCardPoorQuality:
            stateKey = @"iqa_card_poor_quality";
            [self setBcgColor:[UIColor colorWithRed:0.984 green:0.901 blue:0.796 alpha:1] borderColor:[UIColor colorWithRed:0.937 green:0.678 blue:0.454 alpha:1]];
            break;
        case AAIIQAWarnCodeTooSmallCard:
            stateKey = @"too_small_card";
            [self setBcgColor:[UIColor colorWithRed:0.984 green:0.901 blue:0.796 alpha:1] borderColor:[UIColor colorWithRed:0.937 green:0.678 blue:0.454 alpha:1]];
            break;
        case AAIIQAWarnCodeEdgeCross:
            stateKey = @"iqa_min_gap_ratio";
            [self setBcgColor:[UIColor colorWithRed:0.984 green:0.901 blue:0.796 alpha:1] borderColor:[UIColor colorWithRed:0.937 green:0.678 blue:0.454 alpha:1]];
            
            break;
        case AAIIQAWarnCodeGood:
            stateKey = @"hold_phone";
            [self setBcgColor:[UIColor colorWithRed:0.827 green:0.937 blue:0.811 alpha:1] borderColor:[UIColor colorWithRed:0.462 green:0.568 blue:0.513 alpha:1]];
            
            break;
        default:
            break;
    }
    
    if (stateKey) {
        _descLabel.text = [AAIIQACommUtil localStrForKey:stateKey];
    } else {
        _descLabel.text = nil;
    }
    
}

- (void)iqaOnDetectionSucceed:(UIImage *)rawImage
{
    // You can adjust the bcgColor, borderColor to meet your needs.
    [self setBcgColor:[UIColor colorWithRed:0.827 green:0.937 blue:0.811 alpha:1] borderColor:[UIColor colorWithRed:0.462 green:0.568 blue:0.513 alpha:1]];
    _descLabel.text = @"sucess";
}

@end
