//
//  AAICustomTipView3.m
//  AAIGlobalIQASDKDemo
//
//  Created by advance on 2023/5/22.
//

#import "AAICustomTipView3.h"

@interface TestViewController3: UIViewController
@end
@implementation TestViewController3

- (void)viewDidLoad
{
    [super viewDidLoad];
    self.view.backgroundColor = UIColor.whiteColor;
    
    UIButton *btn = [UIButton buttonWithType:UIButtonTypeSystem];
    [btn setTitle:@"TakePhoto" forState:UIControlStateNormal];
    btn.frame = CGRectMake(20, 80, 80, 40);
    [self.view addSubview:btn];
    [btn addTarget:self action:@selector(tapTakePhotoBtn) forControlEvents:UIControlEventTouchUpInside];
}

- (void)tapTakePhotoBtn
{
    if ([self.presentingViewController isKindOfClass:[UINavigationController class]]) {
        UINavigationController *sdkNaVC = (UINavigationController *)self.presentingViewController;
        // 1.Close current view controller first
        [sdkNaVC dismissViewControllerAnimated:YES completion:^{
            // Do not push your view controller here, because the IQA SDK will keep scanning the document
            // until you closed this scan page. So we should close the SDK page first then can we show the other view controller.
            // 2. Close the SDK page
            [sdkNaVC.presentingViewController dismissViewControllerAnimated:YES completion:^{
                // 3. Demo: Show take photo page
            }];
             
        }];
    }
}

- (void)dealloc
{
    NSLog(@"✅TestViewController3 is released");
}

@end
#pragma mark - portrait

@implementation AAICustomPorTipView3

- (instancetype)initWithFrame:(CGRect)frame
{
    self = [super initWithFrame:frame];
    if (self) {
        [self createSubviews];
    }
    return self;
}

- (void)createSubviews
{
    UIView *contentView = [self createContentView];
    [self addSubview:contentView];
    NSArray *allCons = @[
        [contentView.leftAnchor constraintEqualToAnchor:self.leftAnchor],
        [contentView.rightAnchor constraintEqualToAnchor:self.rightAnchor],
        [contentView.centerYAnchor constraintEqualToAnchor:self.centerYAnchor constant:0],
    ];
    NSLayoutConstraint *w = allCons.lastObject;
    w.priority = UILayoutPriorityDefaultLow;
    
    [NSLayoutConstraint activateConstraints:allCons];
}

- (UIView *)createContentView
{
    AAIGlobalIQAUIConfig *uiConfig = [AAIGlobalIQASDK sdkConfig].uiConfig;
    UIView *contentView = [[UIView alloc] init];
    contentView.translatesAutoresizingMaskIntoConstraints = NO;
    
    UIImageView *imgView = [[UIImageView alloc] init];
    imgView.translatesAutoresizingMaskIntoConstraints = NO;
    [contentView addSubview:imgView];
    imgView.hidden = !(uiConfig.tipIconVisible);
    
    UILabel *label = [[UILabel alloc] init];
    label.font = [AAIIQACommUtil fontWithSize:14 isBold:NO];
    label.textColor = uiConfig.primaryTextColor;
    label.numberOfLines = 0;
    label.textAlignment = NSTextAlignmentCenter;
    label.translatesAutoresizingMaskIntoConstraints = NO;
    [contentView addSubview:label];
    
    // Demo: Add help button
    UIButton *helpBtn = [UIButton buttonWithType:UIButtonTypeSystem];
    [helpBtn setTitle:@"扫描遇到问题?" forState:UIControlStateNormal];
    [helpBtn setTitleColor:uiConfig.primaryTextColor forState:UIControlStateNormal];
    helpBtn.translatesAutoresizingMaskIntoConstraints = NO;
    [contentView addSubview:helpBtn];
    [helpBtn addTarget:self action:@selector(tapHelpBtn) forControlEvents:UIControlEventTouchUpInside];
    
    NSArray *allCons = @[
        [imgView.topAnchor constraintEqualToAnchor:contentView.topAnchor],
        [imgView.widthAnchor constraintEqualToConstant:50],
        [imgView.heightAnchor constraintEqualToConstant:50],
        [imgView.centerXAnchor constraintEqualToAnchor:contentView.centerXAnchor],
        
        [label.topAnchor constraintEqualToAnchor:imgView.bottomAnchor constant:14],
        
        [imgView.leftAnchor constraintGreaterThanOrEqualToAnchor:contentView.leftAnchor constant:0],
        [imgView.rightAnchor constraintLessThanOrEqualToAnchor:contentView.rightAnchor constant:0],
 
        [label.leftAnchor constraintEqualToAnchor:contentView.leftAnchor constant:20],
        [label.rightAnchor constraintEqualToAnchor:contentView.rightAnchor constant:-20],
        
        [helpBtn.topAnchor constraintEqualToAnchor:label.bottomAnchor constant:20],
        [helpBtn.centerXAnchor constraintEqualToAnchor:contentView.centerXAnchor],
        [helpBtn.heightAnchor constraintEqualToConstant:40],
        
        [contentView.bottomAnchor constraintEqualToAnchor:helpBtn.bottomAnchor constant:0]
    ];
    
    [NSLayoutConstraint activateConstraints:allCons];

    _iconImgView = imgView;
    _textLabel = label;
    _helpBtn = helpBtn;
    _helpBtn.hidden = YES;
    
    return contentView;
}

#pragma mark AAIIQADetectionDelegate

- (void)iqaOnDetectionWarn:(AAIIQAWarnCode)warnCode
{
    NSString *stateKey = nil;
    NSString *iconImgName = nil;
    switch (warnCode) {
        case AAIIQAWarnCodeNoCard:
            stateKey = @"no_card";
            iconImgName = @"iqa_scan_warning";
            break;
        case AAIIQAWarnCodeCardPoorQuality:
            stateKey = @"iqa_card_poor_quality";
            iconImgName = @"iqa_scan_warning";
            break;
        case AAIIQAWarnCodeTooSmallCard:
            stateKey = @"too_small_card";
            iconImgName = @"iqa_scan_warning";
            break;
        case AAIIQAWarnCodeEdgeCross:
            stateKey = @"iqa_min_gap_ratio";
            iconImgName = @"iqa_scan_warning";
            break;
        case AAIIQAWarnCodeGood:
            stateKey = @"hold_phone";
            iconImgName = @"iqa_scan_processing";
            break;
        default:
            break;
    }
    
    if (iconImgName) {
        _iconImgView.image = [AAIIQACommUtil imgWithName:iconImgName];
    } else {
        _iconImgView.image = nil;
    }
    
    if (stateKey) {
        _textLabel.text = [AAIIQACommUtil localStrForKey:stateKey];
    } else {
        _textLabel.text = nil;
    }
}

- (void)iqaOnDetectionRemainTimeChanged:(NSInteger)remainTime totalTime:(NSInteger)totalTime contentView:(UIView *)contentView
{
    // Demo: The help button will become visible after 5 seconds.
    if (totalTime - remainTime == 5) {
        _helpBtn.hidden = NO;
    }
    NSLog(@"%ld", (long)remainTime);
}

- (void)iqaOnDetectionSucceed:(UIImage *)rawImage
{
    _iconImgView.image = [AAIIQACommUtil imgWithName:@"iqa_scan_successfully"];
    _textLabel.text = [AAIIQACommUtil localStrForKey:@"iqa_scan_successfully"];
}

- (void)tapHelpBtn
{
    // 1. Find AAIIQAScanController
    UIResponder *resp = self.nextResponder;
    AAIIQAScanController *scanVC = nil;
    while (resp != nil) {
        if ([resp isKindOfClass:[AAIIQAScanController class]]) {
            scanVC = (AAIIQAScanController *)resp;
            break;
        }
        resp = resp.nextResponder;
    }
    
    if (!scanVC) {
        return;
    }
    
    /*
    // The view of 'AAIIQAScanController'
    // You can add customize view on this view
    AAIIQAScanMainView *contentView = scanVC.view;
    
    // The SDK's internal navigation controller
    UINavigationController *sdkNaVC = scanVC.navigationController;
    */
    
    // 2. Demo: Present your customized view controller
    UIViewController *demoVC = [[TestViewController3 alloc] init];
    if (@available(iOS 15.0, *)) {
        /*
        demoVC.modalPresentationStyle = UIModalPresentationPopover;
        UIPopoverPresentationController *popover = demoVC.popoverPresentationController;
        UISheetPresentationController *sheet = popover.adaptiveSheetPresentationController;
        sheet.detents = @[UISheetPresentationControllerDetent.mediumDetent];
        // ⚠️Note set the 'prefersGrabberVisible' to YES will cause the demoVC and SDK page memory leak.
        sheet.prefersGrabberVisible = NO;
         */
        
        demoVC.modalPresentationStyle = UIModalPresentationPageSheet;
        UISheetPresentationController *sheet = demoVC.sheetPresentationController;
        sheet.detents = @[UISheetPresentationControllerDetent.mediumDetent];
        // ⚠️Note set the 'prefersGrabberVisible' to YES will cause the demoVC and SDK page memory leak.
        sheet.prefersGrabberVisible = NO;
    }

    [scanVC presentViewController:demoVC animated:YES completion:nil];
}

@end

#pragma mark - landscape

@implementation AAICustomLanTipView3
- (instancetype)initWithFrame:(CGRect)frame
{
    self = [super initWithFrame:frame];
    if (self) {
        self.layer.cornerRadius = 2;
        [self createSubviews];
    }
    return self;
}

- (void)createSubviews
{
    UILabel *label = [[UILabel alloc] init];
    label.font = [AAIIQACommUtil fontWithSize:14 isBold:NO];
    label.textColor = [UIColor whiteColor];
    label.numberOfLines = 0;
    label.textAlignment = NSTextAlignmentCenter;
    label.translatesAutoresizingMaskIntoConstraints = NO;
    [self addSubview:label];
    _label = label;
    
    NSArray *allCons = @[
        [label.topAnchor constraintEqualToAnchor:self.topAnchor constant:5],
        [label.leftAnchor constraintEqualToAnchor:self.leftAnchor constant:13],
        [label.rightAnchor constraintEqualToAnchor:self.rightAnchor constant:-13],
        [label.bottomAnchor constraintEqualToAnchor:self.bottomAnchor constant:-5],
    ];
    [NSLayoutConstraint activateConstraints:allCons];
}

#pragma mark AAIIQADetectionDelegate

- (void)iqaOnDetectionWarn:(AAIIQAWarnCode)warnCode
{
    NSString *stateKey = nil;
    switch (warnCode) {
        case AAIIQAWarnCodeNoCard:
            stateKey = @"no_card";
            self.backgroundColor = [AAIIQACommUtil colorWithHexRGB:0xDE1C11 alpha:0.6];
            break;
        case AAIIQAWarnCodeCardPoorQuality:
            stateKey = @"iqa_card_poor_quality";
            self.backgroundColor = [AAIIQACommUtil colorWithHexRGB:0xDE1C11 alpha:0.6];
            break;
        case AAIIQAWarnCodeTooSmallCard:
            stateKey = @"too_small_card";
            self.backgroundColor = [AAIIQACommUtil colorWithHexRGB:0xDE1C11 alpha:0.6];
            break;
        case AAIIQAWarnCodeEdgeCross:
            stateKey = @"iqa_min_gap_ratio";
            self.backgroundColor = [AAIIQACommUtil colorWithHexRGB:0xDE1C11 alpha:0.6];
            break;
        case AAIIQAWarnCodeGood:
            stateKey = @"hold_phone";
            self.backgroundColor = [AAIIQACommUtil colorWithHexRGB:0x008814 alpha:0.6];
            break;
        default:
            break;
    }
    
    if (stateKey) {
        _label.text = [AAIIQACommUtil localStrForKey:stateKey];
    } else {
        _label.text = nil;
    }
    
}

- (void)iqaOnDetectionSucceed:(UIImage *)rawImage
{
    _label.text = [AAIIQACommUtil localStrForKey:@"iqa_scan_successfully"];
}

@end

